"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var image_source_1 = require("tns-core-modules/image-source");
var imagelabeling_common_1 = require("./imagelabeling-common");
var MLKitImageLabeling = /** @class */ (function (_super) {
    __extends(MLKitImageLabeling, _super);
    function MLKitImageLabeling() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MLKitImageLabeling.prototype.createDetector = function () {
        return getDetector(this.confidenceThreshold);
    };
    MLKitImageLabeling.prototype.createSuccessListener = function () {
        var _this = this;
        return new com.google.android.gms.tasks.OnSuccessListener({
            onSuccess: function (labels) {
                if (labels.size() === 0)
                    return;
                // const imageSource = new ImageSource();
                // imageSource.setNativeSource(this.lastVisionImage.getBitmapForDebugging());
                var result = {
                    // imageSource: imageSource,
                    labels: []
                };
                // see https://github.com/firebase/quickstart-android/blob/0f4c86877fc5f771cac95797dffa8bd026dd9dc7/mlkit/app/src/main/java/com/google/firebase/samples/apps/mlkit/textrecognition/TextRecognitionProcessor.java#L62
                for (var i = 0; i < labels.size(); i++) {
                    var label = labels.get(i);
                    result.labels.push({
                        text: label.getLabel(),
                        confidence: label.getConfidence()
                    });
                }
                _this.notify({
                    eventName: MLKitImageLabeling.scanResultEvent,
                    object: _this,
                    value: result
                });
            }
        });
    };
    return MLKitImageLabeling;
}(imagelabeling_common_1.MLKitImageLabeling));
exports.MLKitImageLabeling = MLKitImageLabeling;
function getDetector(confidenceThreshold) {
    var labelDetectorOptions = new com.google.firebase.ml.vision.label.FirebaseVisionLabelDetectorOptions.Builder()
        .setConfidenceThreshold(confidenceThreshold)
        .build();
    return com.google.firebase.ml.vision.FirebaseVision.getInstance().getVisionLabelDetector(labelDetectorOptions);
}
function labelImage(options) {
    return new Promise(function (resolve, reject) {
        try {
            var firebaseVisionLabelDetector_1 = getDetector(options.confidenceThreshold || 0.5);
            var onSuccessListener = new com.google.android.gms.tasks.OnSuccessListener({
                onSuccess: function (labels) {
                    var result = {
                        labels: []
                    };
                    for (var i = 0; i < labels.size(); i++) {
                        var label = labels.get(i);
                        result.labels.push({
                            text: label.getLabel(),
                            confidence: label.getConfidence()
                        });
                    }
                    console.log(">>> image labeling result: " + JSON.stringify(result));
                    resolve(result);
                    firebaseVisionLabelDetector_1.close();
                }
            });
            var onFailureListener = new com.google.android.gms.tasks.OnFailureListener({
                onFailure: function (exception) { return reject(exception.getMessage()); }
            });
            firebaseVisionLabelDetector_1
                .detectInImage(getImage(options))
                .addOnSuccessListener(onSuccessListener)
                .addOnFailureListener(onFailureListener);
        }
        catch (ex) {
            console.log("Error in firebase.mlkit.labelImage: " + ex);
            reject(ex);
        }
    });
}
exports.labelImage = labelImage;
function getImage(options) {
    var image = options.image instanceof image_source_1.ImageSource ? options.image.android : options.image.imageSource.android;
    return com.google.firebase.ml.vision.common.FirebaseVisionImage.fromBitmap(image);
}
