"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var image_source_1 = require("tns-core-modules/image-source");
var landmarkrecognition_common_1 = require("./landmarkrecognition-common");
var MLKitLandmarkRecognition = /** @class */ (function (_super) {
    __extends(MLKitLandmarkRecognition, _super);
    function MLKitLandmarkRecognition() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MLKitLandmarkRecognition.prototype.createDetector = function () {
        return getDetector(this.maxResults);
    };
    MLKitLandmarkRecognition.prototype.createSuccessListener = function () {
        var _this = this;
        return new com.google.android.gms.tasks.OnSuccessListener({
            onSuccess: function (landmarks) {
                if (landmarks.size() === 0)
                    return;
                // const imageSource = new ImageSource();
                // imageSource.setNativeSource(this.lastVisionImage.getBitmapForDebugging());
                var result = {
                    // imageSource: imageSource,
                    landmarks: []
                };
                for (var i = 0; i < landmarks.size(); i++) {
                    var landmark = landmarks.get(i);
                    result.landmarks.push({
                        name: landmark.getLandmark(),
                        confidence: landmark.getConfidence()
                    });
                }
                _this.notify({
                    eventName: MLKitLandmarkRecognition.scanResultEvent,
                    object: _this,
                    value: result
                });
            }
        });
    };
    return MLKitLandmarkRecognition;
}(landmarkrecognition_common_1.MLKitLandmarkRecognition));
exports.MLKitLandmarkRecognition = MLKitLandmarkRecognition;
function getDetector(confidenceThreshold) {
    var landmarkDetectorOptions = new com.google.firebase.ml.vision.cloud.FirebaseVisionCloudDetectorOptions.Builder()
        .setMaxResults(confidenceThreshold)
        .build();
    return com.google.firebase.ml.vision.FirebaseVision.getInstance().getVisionCloudLandmarkDetector(landmarkDetectorOptions);
}
function recognizeLandmark(options) {
    return new Promise(function (resolve, reject) {
        try {
            var firebaseVisionLandmarkDetector_1 = getDetector(options.maxResults || 10);
            var onSuccessListener = new com.google.android.gms.tasks.OnSuccessListener({
                onSuccess: function (landmarks) {
                    var result = {
                        landmarks: []
                    };
                    for (var i = 0; i < landmarks.size(); i++) {
                        var landmark = landmarks.get(i);
                        result.landmarks.push({
                            name: landmark.getLandmark(),
                            confidence: landmark.getConfidence()
                        });
                    }
                    resolve(result);
                    firebaseVisionLandmarkDetector_1.close();
                }
            });
            var onFailureListener = new com.google.android.gms.tasks.OnFailureListener({
                onFailure: function (exception) { return reject(exception.getMessage()); }
            });
            firebaseVisionLandmarkDetector_1
                .detectInImage(getImage(options))
                .addOnSuccessListener(onSuccessListener)
                .addOnFailureListener(onFailureListener);
        }
        catch (ex) {
            console.log("Error in firebase.mlkit.recognizeLandmark: " + ex);
            reject(ex);
        }
    });
}
exports.recognizeLandmark = recognizeLandmark;
function getImage(options) {
    var image = options.image instanceof image_source_1.ImageSource ? options.image.android : options.image.imageSource.android;
    return com.google.firebase.ml.vision.common.FirebaseVisionImage.fromBitmap(image);
}
