"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var image_source_1 = require("tns-core-modules/image-source");
var landmarkrecognition_common_1 = require("./landmarkrecognition-common");
var MLKitLandmarkRecognition = /** @class */ (function (_super) {
    __extends(MLKitLandmarkRecognition, _super);
    function MLKitLandmarkRecognition() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MLKitLandmarkRecognition.prototype.createDetector = function () {
        return getDetector(this.maxResults);
    };
    MLKitLandmarkRecognition.prototype.createSuccessListener = function () {
        var _this = this;
        return function (landmarks, error) {
            if (error !== null) {
                console.log(error.localizedDescription);
            }
            else if (landmarks !== null && landmarks.count > 0) {
                var result = {
                    landmarks: []
                };
                for (var i = 0, l = landmarks.count; i < l; i++) {
                    var landmark = landmarks.objectAtIndex(i);
                    console.log(">> detected landmark: " + landmark);
                    result.landmarks.push({
                        name: landmark.landmark,
                        confidence: landmark.confidence
                    });
                }
                console.log(">>> notify " + MLKitLandmarkRecognition.scanResultEvent + " with " + JSON.stringify(result));
                _this.notify({
                    eventName: MLKitLandmarkRecognition.scanResultEvent,
                    object: _this,
                    value: result
                });
            }
        };
    };
    MLKitLandmarkRecognition.prototype.rotateRecording = function () {
        return false;
    };
    return MLKitLandmarkRecognition;
}(landmarkrecognition_common_1.MLKitLandmarkRecognition));
exports.MLKitLandmarkRecognition = MLKitLandmarkRecognition;
function getDetector(maxResults) {
    var firVision = FIRVision.vision();
    var fIRVisionCloudDetectorOptions = FIRVisionCloudDetectorOptions.alloc();
    fIRVisionCloudDetectorOptions.maxResults = maxResults;
    return firVision.cloudLandmarkDetectorWithOptions(fIRVisionCloudDetectorOptions);
}
function recognizeLandmark(options) {
    return new Promise(function (resolve, reject) {
        try {
            var landmarkDetector = getDetector(options.maxResults || 10);
            landmarkDetector.detectInImageCompletion(getImage(options), function (landmarks, error) {
                if (error !== null) {
                    reject(error.localizedDescription);
                }
                else if (landmarks !== null) {
                    var result = {
                        landmarks: []
                    };
                    for (var i = 0, l = landmarks.count; i < l; i++) {
                        var landmark = landmarks.objectAtIndex(i);
                        console.log(">> detected landmark: " + landmark);
                        result.landmarks.push({
                            name: landmark.landmark,
                            confidence: landmark.confidence
                        });
                    }
                    resolve(result);
                }
            });
        }
        catch (ex) {
            console.log("Error in firebase.mlkit.recognizeLandmark: " + ex);
            reject(ex);
        }
    });
}
exports.recognizeLandmark = recognizeLandmark;
function getImage(options) {
    var image = options.image instanceof image_source_1.ImageSource ? options.image.ios : options.image.imageSource.ios;
    return FIRVisionImage.alloc().initWithImage(image);
}
