"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var image_source_1 = require("tns-core-modules/image-source");
var textrecognition_common_1 = require("./textrecognition-common");
var MLKitTextRecognition = /** @class */ (function (_super) {
    __extends(MLKitTextRecognition, _super);
    function MLKitTextRecognition() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MLKitTextRecognition.prototype.createDetector = function () {
        return com.google.firebase.ml.vision.FirebaseVision.getInstance().getVisionTextDetector();
    };
    MLKitTextRecognition.prototype.createSuccessListener = function () {
        var _this = this;
        return new com.google.android.gms.tasks.OnSuccessListener({
            onSuccess: function (textBlocks) {
                if (textBlocks.getBlocks().size() === 0)
                    return;
                var blocks = textBlocks.getBlocks();
                // const imageSource = new ImageSource();
                // imageSource.setNativeSource(this.lastVisionImage.getBitmapForDebugging());
                var result = {
                    features: []
                };
                // see https://github.com/firebase/quickstart-android/blob/0f4c86877fc5f771cac95797dffa8bd026dd9dc7/mlkit/app/src/main/java/com/google/firebase/samples/apps/mlkit/textrecognition/TextRecognitionProcessor.java#L62
                for (var i = 0; i < blocks.size(); i++) {
                    var textBlock = blocks.get(i);
                    result.features.push({
                        text: textBlock.getText()
                    });
                }
                _this.notify({
                    eventName: MLKitTextRecognition.scanResultEvent,
                    object: _this,
                    value: result
                });
            }
        });
    };
    return MLKitTextRecognition;
}(textrecognition_common_1.MLKitTextRecognition));
exports.MLKitTextRecognition = MLKitTextRecognition;
function recognizeText(options) {
    return new Promise(function (resolve, reject) {
        try {
            var firebaseVisionTextDetector_1 = com.google.firebase.ml.vision.FirebaseVision.getInstance().getVisionTextDetector();
            var onSuccessListener = new com.google.android.gms.tasks.OnSuccessListener({
                onSuccess: function (textBlocks) {
                    var blocks = textBlocks.getBlocks();
                    var result = {
                        features: []
                    };
                    // see https://github.com/firebase/quickstart-android/blob/0f4c86877fc5f771cac95797dffa8bd026dd9dc7/mlkit/app/src/main/java/com/google/firebase/samples/apps/mlkit/textrecognition/TextRecognitionProcessor.java#L62
                    for (var i = 0; i < blocks.size(); i++) {
                        var textBlock = blocks.get(i);
                        result.features.push({
                            text: textBlock.getText()
                        });
                    }
                    resolve(result);
                    firebaseVisionTextDetector_1.close();
                }
            });
            var onFailureListener = new com.google.android.gms.tasks.OnFailureListener({
                onFailure: function (exception) { return reject(exception.getMessage()); }
            });
            firebaseVisionTextDetector_1
                .detectInImage(getImage(options))
                .addOnSuccessListener(onSuccessListener)
                .addOnFailureListener(onFailureListener);
        }
        catch (ex) {
            console.log("Error in firebase.mlkit.recognizeText: " + ex);
            reject(ex);
        }
    });
}
exports.recognizeText = recognizeText;
// TODO move
function getImage(options) {
    var image = options.image instanceof image_source_1.ImageSource ? options.image.android : options.image.imageSource.android;
    return com.google.firebase.ml.vision.common.FirebaseVisionImage.fromBitmap(image);
}
