"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var image_source_1 = require("tns-core-modules/image-source");
var textrecognition_common_1 = require("./textrecognition-common");
var MLKitTextRecognition = /** @class */ (function (_super) {
    __extends(MLKitTextRecognition, _super);
    function MLKitTextRecognition() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MLKitTextRecognition.prototype.createDetector = function () {
        var firVision = FIRVision.vision();
        return firVision.textDetector();
    };
    MLKitTextRecognition.prototype.createSuccessListener = function () {
        var _this = this;
        return function (features, error) {
            if (error !== null) {
                console.log(error.localizedDescription);
            }
            else if (features !== null && features.count > 0) {
                var result = {
                    features: []
                };
                for (var i = 0, l = features.count; i < l; i++) {
                    var feature = features.objectAtIndex(i);
                    // Note that fetching these details works, but there's currently no added value
                    /*
                      if (feature instanceof FIRVisionTextBlock) {
                        const textBlock = <FIRVisionTextBlock>feature;
                        for (let j = 0, k = textBlock.lines.count; j < k; j++) {
                          const textBlockLine: FIRVisionTextLine = textBlock.lines.objectAtIndex(j);
                          for (let a = 0, m = textBlockLine.elements.count; a < m; a++) {
                            const element: FIRVisionTextElement = textBlockLine.elements.objectAtIndex(a);
                            console.log("FIRVisionTextBlock text: " + element.text);
                          }
                        }
                      }
                      if (feature instanceof FIRVisionTextLine) {
                        for (let a = 0, m = feature.elements.count; a < m; a++) {
                          const element: FIRVisionTextElement = feature.elements.objectAtIndex(a);
                          console.log("FIRVisionTextLine text: " + element.text);
                        }
                      }
                    */
                    result.features.push({
                        text: feature.text,
                    });
                }
                _this.notify({
                    eventName: MLKitTextRecognition.scanResultEvent,
                    object: _this,
                    value: result
                });
            }
        };
    };
    MLKitTextRecognition.prototype.rotateRecording = function () {
        return true;
    };
    return MLKitTextRecognition;
}(textrecognition_common_1.MLKitTextRecognition));
exports.MLKitTextRecognition = MLKitTextRecognition;
function recognizeText(options) {
    return new Promise(function (resolve, reject) {
        try {
            var firVision = FIRVision.vision();
            var textDetector = firVision.textDetector();
            textDetector.detectInImageCompletion(getImage(options), function (features, error) {
                if (error !== null) {
                    reject(error.localizedDescription);
                }
                else if (features !== null) {
                    var result = {
                        features: []
                    };
                    for (var i = 0, l = features.count; i < l; i++) {
                        var feature = features.objectAtIndex(i);
                        result.features.push({
                            text: feature.text,
                        });
                    }
                    resolve(result);
                }
            });
        }
        catch (ex) {
            console.log("Error in firebase.mlkit.recognizeText: " + ex);
            reject(ex);
        }
    });
}
exports.recognizeText = recognizeText;
// TODO move to a common file
function getImage(options) {
    var image = options.image instanceof image_source_1.ImageSource ? options.image.ios : options.image.imageSource.ios;
    return FIRVisionImage.alloc().initWithImage(image);
}
